@@ -7,4 +7,6 @@ def test_example_against_schema_which_should_succeed():
     from metadata.latest.example import OEMETADATA_LATEST_EXAMPLE
     from metadata.latest.schema import OEMETADATA_LATEST_SCHEMA
 
-    assert jsonschema.validate(OEMETADATA_LATEST_EXAMPLE, OEMETADATA_LATEST_SCHEMA) == None
+    assert (
+        jsonschema.validate(OEMETADATA_LATEST_EXAMPLE, OEMETADATA_LATEST_SCHEMA) == None
+    )
